@@ -1,4 +1,4 @@
 library(testthat)
-library(MortalityLaws)
+expect_message(library(MortalityLaws))
 
 test_check("MortalityLaws")
